@@ -1,11 +1,9 @@
 import math
-from ctypes import c_uint32, c_uint64, sizeof
+from ctypes import Structure, c_uint32, c_uint64, sizeof
 from distutils.version import LooseVersion
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Tuple, Type, TypeVar
 
-from _ctypes import Structure
-
 from strongarm.logger import strongarm_logger
 from strongarm.macho.arch_independent_structs import (
     ArchIndependentStructure,
@@ -63,6 +61,29 @@ class InvalidAddressError(Exception):
     """Raised when a client asks for bytes at an address outside the binary."""
 
 
+class DynamicLibrary:
+    """Linked dylib
+    https://opensource.apple.com/source/dyld/dyld-96.2/src/ImageLoaderMachO.cpp.auto.html
+    https://opensource.apple.com/source/cctools/cctools-576/ld/dylibs.c.auto.html
+    """
+
+    # Stand-in for rare cases in which we're unable to parse a dylib's path
+    UNKNOWN_NAME = "<unknown dylib>"
+
+    def __init__(self, macho_binary: "MachoBinary", dylib_command: DylibCommandStruct) -> None:
+        self.cmd = dylib_command
+
+        start_address = self.cmd.binary_offset + self.cmd.dylib.name.offset
+        dylib_name = macho_binary.get_full_string_from_start_address(start_address, virtual=False)
+
+        self.name = dylib_name or DynamicLibrary.UNKNOWN_NAME
+        self.checksum = self.cmd.dylib.timestamp
+        self.current_version = self.cmd.dylib.current_version  # maxVersion
+        self.compatibility_version = self.cmd.dylib.compatibility_version  # minVersion
+        self.required = self.cmd.cmd != MachoLoadCommands.LC_LOAD_WEAK_DYLIB
+        self.re_exported = self.cmd.cmd != MachoLoadCommands.LC_REEXPORT_DYLIB
+
+
 class MachoSegment:
     def __init__(self, segment_command: MachoSegmentCommandStruct) -> None:
         self.cmd = segment_command
@@ -152,18 +173,20 @@ class MachoBinary:
         # Segment and section commands from Mach-O header
         self.segments: List[MachoSegment] = []
         self.sections: List[MachoSection] = []
+
         # Interesting Mach-O sections
+        self.linked_dylibs: List[DynamicLibrary] = []
+        self.id_dylib: Optional[DynamicLibrary] = None
+
         self._dysymtab: Optional[MachoDysymtabCommandStruct] = None
         self._symtab: Optional[MachoSymtabCommandStruct] = None
         self._encryption_info: Optional[MachoEncryptionInfoStruct] = None
         self._dyld_info: Optional[MachoDyldInfoCommandStruct] = None
         self._dyld_export_trie: Optional[MachoLinkeditDataCommandStruct] = None
         self._dyld_chained_fixups: Optional[MachoLinkeditDataCommandStruct] = None
-        self.load_dylib_commands: List[DylibCommandStruct] = []
         self._code_signature_cmd: Optional[MachoLinkeditDataCommandStruct] = None
         self._function_starts_cmd: Optional[MachoLinkeditDataCommandStruct] = None
         self._functions_list: Optional[Set[VirtualMemoryPointer]] = None
-        self._id_dylib_cmd: Optional[DylibCommandStruct] = None
         self._build_version_cmd: Optional[MachoBuildVersionCommandStruct] = None
         self._build_tool_versions: Optional[List[MachoBuildToolVersionStruct]] = None
 
@@ -286,8 +309,6 @@ class MachoBinary:
             offset: Slice offset to first segment command
             ncmds: Number of load commands to parse, as declared by the header's ncmds field
         """
-        self.load_dylib_commands = []
-
         for i in range(ncmds):
             load_command = self.read_struct(offset, MachoLoadCommandStruct)
 
@@ -320,7 +341,10 @@ class MachoBinary:
 
             elif load_command.cmd in [MachoLoadCommands.LC_LOAD_DYLIB, MachoLoadCommands.LC_LOAD_WEAK_DYLIB]:
                 dylib_load_command = self.read_struct(offset, DylibCommandStruct)
-                self.load_dylib_commands.append(dylib_load_command)
+                dependent_library_info = DynamicLibrary(self, dylib_load_command)
+                if dependent_library_info.name == DynamicLibrary.UNKNOWN_NAME:
+                    logger.warning(f"Could not read name of LC_LOAD_(WEAK_)DYLIB command at index {i}, offset {offset}")
+                self.linked_dylibs.append(dependent_library_info)
 
             elif load_command.cmd == MachoLoadCommands.LC_CODE_SIGNATURE:
                 self._code_signature_cmd = self.read_struct(offset, MachoLinkeditDataCommandStruct)
@@ -329,7 +353,10 @@ class MachoBinary:
                 self._function_starts_cmd = self.read_struct(offset, MachoLinkeditDataCommandStruct)
 
             elif load_command.cmd == MachoLoadCommands.LC_ID_DYLIB:
-                self._id_dylib_cmd = self.read_struct(offset, DylibCommandStruct)
+                id_dylib_command = self.read_struct(offset, DylibCommandStruct)
+                self.id_dylib = DynamicLibrary(self, id_dylib_command)
+                if self.id_dylib.name == DynamicLibrary.UNKNOWN_NAME:
+                    logger.warning(f"Could not read name of LC_ID_DYLIB command at index {i}, offset {offset}")
                 # This load command should only be present for dylibs. Validate this assumption
                 assert self.file_type == MachoFileType.MH_DYLIB
 
@@ -346,7 +373,7 @@ class MachoBinary:
             offset += load_command.cmdsize
 
     def read_struct(self, binary_offset: int, struct_type: Type[AIS], virtual: bool = False) -> AIS:
-        """Given an binary offset, return the structure it describes.
+        """Given a binary offset, return the structure it describes.
 
         Params:
             binary_offset: Address from where to read the bytes.
@@ -600,7 +627,7 @@ class MachoBinary:
         return self.get_bytes(binary_address, size)
 
     def get_contents_from_address(self, address: int, size: int, is_virtual: bool = False) -> bytearray:
-        """Get a bytesarray from a specified address, size and virtualness
+        """Get a bytearray from a specified address, size and virtualness
         TODO(FS): change all methods that use addresses as ints to the VirtualAddress/StaticAddress class pair to better
          express intent
         """
@@ -682,34 +709,30 @@ class MachoBinary:
         range2 = (self.encryption_info.cryptoff, self.encryption_info.cryptoff + self.encryption_info.cryptsize)
         return range1[1] >= range2[0] and range2[1] >= range1[0]
 
-    def dylib_for_library_ordinal(self, library_ordinal: int) -> Optional[DylibCommandStruct]:
+    def dylib_for_library_ordinal(self, library_ordinal: int) -> Optional[DynamicLibrary]:
         """Retrieve the library information for the 'library ordinal' value, or None if no entry exists there.
         Library ordinals are 1-indexed.
 
         https://opensource.apple.com/source/cctools/cctools-795/include/mach-o/loader.h
         """
-        idx = library_ordinal - 1
-        # library ordinals are 1-indexed
-        # if the input is invalid, return None
-        if library_ordinal < 1 or idx >= len(self.load_dylib_commands):
+        try:
+            # library ordinals are 1-indexed
+            return self.linked_dylibs[library_ordinal - 1]
+
+        except KeyError:
             return None
-        return self.load_dylib_commands[idx]
 
     def dylib_name_for_library_ordinal(self, library_ordinal: int) -> str:
         """Read the name of the dynamic library by its library ordinal."""
         source_dylib = self.dylib_for_library_ordinal(library_ordinal)
         if source_dylib:
-            source_name_addr = source_dylib.binary_offset + source_dylib.dylib.name.offset + self.get_virtual_base()
-            source_name = self.get_full_string_from_start_address(source_name_addr)
-            if not source_name:
-                source_name = "<unknown dylib>"
-        else:
-            # we have encountered binaries where the n_desc indicates a nonexistent library ordinal
-            # Netflix.app/frameworks/widevine_cdm_sdk_oemcrypto_release.framework/widevine_cdm_sdk_oemcrypto_release
-            # indicates an ordinal 254, when the binary only actually has 8 LC_LOAD_DYLIB commands.
-            # if we encounter a buggy binary like this, just use a placeholder name
-            source_name = "<unknown dylib>"
-        return source_name
+            return source_dylib.name
+
+        # we have encountered binaries where the n_desc indicates a nonexistent library ordinal
+        # Netflix.app/frameworks/widevine_cdm_sdk_oemcrypto_release.framework/widevine_cdm_sdk_oemcrypto_release
+        # indicates an ordinal 254, when the binary only actually has 8 LC_LOAD_DYLIB commands.
+        # if we encounter a buggy binary like this, just use a placeholder name
+        return DynamicLibrary.UNKNOWN_NAME
 
     def read_pointer_section(self, section_name: str) -> Dict[VirtualMemoryPointer, VirtualMemoryPointer]:
         """Read all the pointers in a section
@@ -1061,16 +1084,10 @@ class MachoBinary:
 
     def dylib_id(self) -> Optional[str]:
         """If the binary contains an LC_ID_DYLIB load command, return the pathname which the binary represents."""
-        if not self._id_dylib_cmd:
-            return None
+        if self.id_dylib:
+            return self.id_dylib.name
 
-        dylib_name_addr = (
-            self._id_dylib_cmd.binary_offset + self._id_dylib_cmd.dylib.name.offset + self.get_virtual_base()
-        )
-        dylib_name = self.get_full_string_from_start_address(dylib_name_addr)
-        if not dylib_name:
-            dylib_name = "<unknown dylib>"
-        return dylib_name
+        return None
 
     def get_minimum_deployment_target(self) -> Optional[LooseVersion]:
         if not self.__minimum_deployment_target and self._build_version_cmd:
